% # 3.a.b
% # Compliant Mechanisms
% # Evaluation of elliptic integrals
% # Howell - Appendix F, pg. 421 - 423

function [Fc,Fi,Ec,Ei]= elliptic (theta_0,k,tol)


% #############################################
% #Initial values: Landen's increasing amplitude
a0=1;
b0=sqrt(1-(k^2));
c0=k;

a=[];
a(1,1)=0.5*(a0+b0);
b=[];
b(1,1)=sqrt(a0*b0);
c=[];
c(1,1)=0.5*(a0-b0);
theta=[];
theta(1,1)=theta_0+atan((b0/a0)*tan(theta_0));
% #############################################

i=2;
comp=1;

% #############################################
% #Gauss's scale of arithmeticogeometrical means
while comp > tol
a(i,1)=0.5*(a(i-1,1)+b(i-1,1));
b(i,1)=sqrt(a(i-1,1)*b(i-1,1));
c(i,1)=0.5*(a(i-1,1)-b(i-1,1));
comp=c(i,1);
i=i+1;
end
% #############################################

for j=2:i
theta(j,1)=theta(j-1,1)+atan((b(j-1,1)/a(j-1,1))*tan(theta(j-1,1)));
m=round((2*theta(j-1,1)-theta(j,1))/pi);
theta(j,1)=theta(j,1) + m*pi;
end

i=i-1;


% #############################################
% #Elliptic Integrals of the first kind
Fc=pi/(2*a(i,1)); %#Complete
Fi=theta(i,1)/(a(i,1)*(2^(i)));% #Incomplete
% #############################################


% #############################################
% #Elliptic Integrals of the second kind
par=(c0^2);%#parenthesis eq. (F.10)
for q=1:i
vc=(2^q)*(c(q,1)^2);
par=par+vc;
end
Ec=Fc*(1-(0.5*par));%#Complete

par1=(c0^2);
par2=0;
for l=1:i
vc1=(2^l)*(c(l,1)^2);
vc2=c(l,1)*sin(theta(l,1));
par1=par1+vc1;
par2=par2+vc2;
end
Ei=Fi+par2-(0.5*par1)*Fi;%#Incomplete
% #############################################
